// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_get_mobile_prefix,
  api_send_code,
  api_apply_order
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    prefixArr: [],
    prefixIndex: 0,
    mobile: '',
    code: '',
    surnName: '',
    firstName: '',
    email: '',
    wxNum: '',
    remark: '',
    startDate: "",
    checkInDate: '',
    codeText: '获取验证码',
    btnCodeDisable: false,
    btnSureDisable: false,
    timer: null,
    data: '',
    canTap: true
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    if (options && options.data) {
      this.setData({
        data: JSON.parse(options.data)
      });
    }


    this.loadPrefix();
    const date = new Date();
    const startDate = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate();
    this.setData({
      startDate: this.data.data.rentTime || startDate
    })
  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {
    let {
      timer
    } = this.data;
    if (timer) {
      clearTimeout(timer);
      timer = null;
    }
  },

  pickerChange: function (e) {
    this.setData({
      prefixIndex: e.detail.value
    });
    this.checkUpParams();
  },
  mobileChange: function (e) {
    let mobile = e.detail.value;
    this.setData({
      mobile: mobile
    });
  },
  codeChange: function (e) {
    let code = e.detail.value;
    this.setData({
      code: code
    });
    this.checkUpParams();
  },
  handleSendCode: function (e) {
    let {
      mobile,
      prefixArr,
      prefixIndex
    } = this.data;
    if (!util.validator.checkMobile(mobile)) {
      util.showToast('请输入正确的手机号码');
      return false;
    }
    let countryId = prefixArr[prefixIndex].id;
    this.sendSmsCode(countryId, mobile);
  },
  loadPrefix: function () {
    let params = {};
    params.data = {
      range: 'B',
      prefix: '1'
    }
    params.url = api_get_mobile_prefix;
    net.req(params).then((res) => {
      if (res && Array.isArray(res) && res.length > 0) {
        let prefixArr = [];
        res.forEach((vvv, iii, aaa) => {
          let {
            list
          } = vvv;
          prefixArr = prefixArr.concat(list);
        });
        this.setData({
          isLoading: false,
          prefixArr: prefixArr
        }, () => {
          for (let i = 0; i < prefixArr.length; i++) {
            let tmp = prefixArr[i];
            if (["86", "086", "+86", "+086"].indexOf(tmp.code) !== -1) {
              this.setData({
                prefixIndex: i
              });
              break;
            }
          }
        });
      }
    });

  },
  sendSmsCode: function (countryId, mobile) {
    let params = {};
    params.url = api_send_code;
    params.data = {
      countryId: countryId,
      mobile: mobile,
      status: "8"
    };
    net.req(params, true).then((res) => {
      this.countDown();
    }, (e) => {
      this.setData({
        btnCodeDisable: false
      });
      let tips = '发送验证码失败';
      if (e) {
        let {
          msg
        } = e;
        if (msg && 'fail' !== msg) {
          tips = msg;
        }
      }
      util.showToast(tips);
    });
    this.setData({
      btnCodeDisable: true
    });
  },
  countDown: function () {
    /*短信验证码倒计时*/
    let timeCount = 60;
    let loop = () => {
      if (timeCount > 0) {
        this.setData({
          codeText: `重新获取（${timeCount}s)`
        });
        timeCount--;
        this.data.timer = setTimeout(loop, 1000);
      } else {
        this.setData({
          codeText: `重新获取`,
          btnCodeDisable: false
        });
        if (this.data.timer) {
          clearTimeout(this.data.timer);
          this.data.timer = null;
        }
      }
    };
    loop();
  },
  timePickerChange: function (e) {
    this.setData({
      checkInDate: e.detail.value
    })

    this.checkUpParams();
  },

  inputChange: function (e) {
    let {
      tag
    } = e.currentTarget.dataset;
    const value = e.detail.value;
    if (tag == "0") {
      this.data.surnName = value;
    } else if (tag == "1") {
      this.data.firstName = value;
    } else if (tag == "2") {
      this.data.email = value;
    } else if (tag == "3") {
      this.data.wxNum = value;
    } else {
      this.data.remark = value;
    }
    this.checkUpParams();
  },

  checkUpParams: function () {
    const {
      mobile,
      code,
      surnName,
      firstName,
      email,
      wxNum,
      checkInDate
    } = this.data;

    if (util.validator.checkMobile(mobile) && util.validator.checkCode(code) &&
      surnName.length && firstName.length && util.validator.checkEmail(email) &&
      wxNum.length > 4 && checkInDate.length) {
      this.setData({
        btnSureDisable: true
      })
    }
  },

  sureBtnAction: function () {
    const obj = this.data.data;
    const {
      mobile,
      code,
      surnName,
      firstName,
      email,
      wxNum,
      checkInDate,
      remark,
      prefixIndex,
      prefixArr
    } = this.data;
    if (this.judgeWithParams() && this.data.canTap) {
      util.showLoading({
        title: "努力提交中..."
      });
      this.data.canTap = false; // 不能连续点击
      const tmp = prefixArr[prefixIndex];
      const that = this;
      let params = {};
      params.url = api_apply_order;

      params.data = {
        countryId: obj.countryId,
        cityId: obj.cityId || "",
        liveTime: checkInDate,
        firstName: surnName,
        lastName: firstName,
        mobilePrefix: tmp.code,
        mobile: mobile,
        email: email,
        wechatId: wxNum,
        extRemarks: remark || "",
        roomAttrId: obj.attrId || "",
        verfyCode: code,
        mobileCountryId: tmp.id,
        houseId: obj.id,
        roomId: obj.roomId || "",
        oneEc: 'miniP',
        twoEc: 'miniP_rentals',
        oneSc: 'nature',
        twoSc: 'nature_search'
      };
      const shareUid = util.getStorageSync('shareUid');
      if (shareUid && shareUid.length) { // 分享用户id
        params.data.shareUid = shareUid;
      }
      const shareCrmUid = util.getStorageSync('shareCrmUid');
      if (shareCrmUid && shareCrmUid.length) { // 分享管理端id
        params.data.shareCrmUid = shareCrmUid;
      }

      net.req(params, true).then((data) => {
        util.hideLoading();
        wx.navigateTo({
          url: '/pages/applySucceed/applySucceed'
        });

        that.data.canTap = true;
      }, (e) => {
        that.data.canTap = true;
        util.hideLoading();
        util.showToast(e.msg);
      });
    }
  },
  judgeWithParams: function () {
    const {
      mobile,
      code,
      surnName,
      firstName,
      email,
      wxNum,
      checkInDate
    } = this.data;
    if (!util.validator.checkMobile(mobile)) {
      util.showToast("请输入正确手机号");
      return false;
    }

    if (!util.validator.checkCode(code)) {
      util.showToast("请输入正确验证码");
      return false;
    }

    if (!surnName.length) {
      util.showToast("请输入您的姓");
      return false;
    }

    if (!firstName.length) {
      util.showToast("请输入您的名");
      return false;
    }

    if (!util.validator.checkEmail(email)) {
      util.showToast("请正确输入您的邮箱，以便我们与您联系");
      return false;
    }

    if (wxNum.length < 6) {
      util.showToast("请正确输入您的微信号，以便我们与您联系");
      return false;
    }

    if (!checkInDate.length) {
      util.showToast("请选择正确的入住日期");
      return false;
    }

    return true;
  }

})