// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
const {
  api_filter_house,
  api_house_list
} = require('../../utils/api.js');
const infinite = "不限",
  upKey = "UPKEY";
Page({

  /**
   * 页面的初始数据
   */
  data: {
    isLoading: true,
    selectAreaOne: null,
    showAreaTwo: null,
    selectAreaTwo: null,
    selectPrice: null,
    selectHomeType: {},
    selectMore: {},
    selectSort: -1000,
    areaData: null,
    areaOne: null,
    areaTwo: null,
    priceData: null,
    minPrice: "",
    maxPrice: "",
    homeTypeData: null,
    moreData: null,
    sortData: null,
    selectdIndex: -1,
    houseList: [],
    canLoadMore: true,
    placeholder: '城市、学校、公寓名称',
    filtrateData: {},
    page: 1,
    pageSize: 8,
    schoolId: null,
    cityId: null,
    tagId: [],
    rentType: [],
    type: [],
    bedRoom: [],
    upData: {}
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let citySelectObj = util.getStorageSync('citySelectObj');
    if (!citySelectObj) {
      wx.reLaunch({
        url: '/pages/citySelect/citySelect',
      });
      return false;
    } else if (options && options.obj) {
      const params = JSON.parse(decodeURIComponent(options.obj));
      this.setData({
        placeholder: params.name
      });
      this.data.cityId = params.cityId;
      const type = parseInt(params.type);
      if (type == 2 || type == 4 || type == 6) {
        this.data.upData[params.filterKey] = params.id;
      }
      this.loadHouseListData();
      this.getFiltrateData(params);

    } else {
      this.setData({
        placeholder: citySelectObj.name
      });
      this.data.cityId = citySelectObj.id;
      this.getFiltrateData();
      this.loadHouseListData();
    }
  },
  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.canLoadMore) {
      this.data.page = this.data.page + 1;
      this.loadHouseListData();
    }
  },


  updateDataCallback: function () {
    let app = getApp();
    if (app.searchData) {
      const params = JSON.parse(decodeURIComponent(app.searchData));
      const {
        name,
        cityId,
        type,
        filterKey,
        id
      } = params;
      this.setData({
        placeholder: name
      })
      this.data.cityId = cityId;
      this.initWithData(); // 重新初始化数据
      const _type = parseInt(type);
      if (_type == 2 || _type == 4 || _type == 6) {
        this.data.upData[filterKey] = id;
      }
      this.loadHouseListData();
      this.getFiltrateData(params);
    } else {
      this.data.page = 0;
      this.loadHouseListData();
    }
  },


  initWithData: function () {
    this.setData({
      selectAreaOne: null,
      showAreaTwo: null,
      selectAreaTwo: null,
      selectPrice: null,
      selectHomeType: {},
      selectMore: {},
      selectSort: -1000,
      minPrice: "",
      maxPrice: '',
      selectdIndex: -1,
      houseList: [],
      canLoadMore: true,
      page: 1,
      schoolId: null,
      tagId: [],
      rentType: [],
      type: [],
      bedRoom: [],
      upData: {}
    })
  },


  getFiltrateData: function (obj) {
    let params = {};
    params.url = api_filter_house;
    params.data = {
      cityId: this.data.cityId
    };
    net.req(params, true).then((data) => {
      if (data) this.dealWithData(data, obj);
    }, (e) => {});
  },


  loadHouseListData: function (obj) {
    const {
      page,
      pageSize,
      cityId,
      selectSort,
      upData
    } = this.data
    let params = {};
    params.url = api_house_list;
    let tem = {
      page: page,
      pageSize: pageSize,
      cityId: Number(cityId),
      order: selectSort || ""
    }
    if (obj) {
      for (const key in obj) {
        if (obj.hasOwnProperty(key)) {
          upData[key] = obj[key];
        } else {
          delete upData[key];
        }
      }
    }
    Object.assign(upData, tem);
    params.data = upData;

    net.req(params, true).then((data) => {
      let list = this.data.houseList || new Array();
      if (!data.list.length && !list.length) {
        this.setData({
          isLoading: false,
          houseList: []
        });
      } else {
        if (!data.list || data.list < this.data.pageSize) {
          this.data.canLoadMore = false; // 这里设置不能加载更多为false，在对应条件要设置为true
        }
        this.setData({
          isLoading: false,
          houseList: list.concat(data.list)
        });
      }

    }, (e) => {
      this.setData({
        isLoading: false,
        houseList: []
      });
    });
  },


  dealWithData: function (data, params) {
    let region = data.region.values;
    this.data.areaData = region;
    let areaOne = new Array(),
      areaTwo = {},
      showAreaTwo = null,
      selectAreaOne = null;
    for (let i = 0, n = region.length; i < n; i++) {
      let obj = region[i];
      if (obj) {
        areaOne.push(obj.name);
        areaTwo[obj.name] = obj.values;
      }
      if (params && (params.type == 2 || params.type == 4 || params.type == 6)) { // 筛选出用户搜索的数据
        if (params.filterKey == obj.keys) {
          selectAreaOne = {
            name: obj.name,
            keys: obj.keys
          };
          showAreaTwo = obj.values;
          for (let j = 0, m = showAreaTwo.length; j < m; j++) {
            const tmp = showAreaTwo[j];
            if (parseInt(params.id) == tmp.value) {
              this.setData({
                selectAreaTwo: params.name
              });
            }
          }
        }
      }
    }

    if (!selectAreaOne && region[0]) { // 默认选中第一个数据
      let obj = region[0];
      selectAreaOne = {
        name: obj.name,
        keys: obj.keys
      };
      showAreaTwo = obj.values;
    }

    let order = null,
      other = null;
    if (data.order && data.order.values) {
      order = data.order.values;
    }

    if (data.other && data.other.values) {
      other = data.other.values;
    }

    let priceData = null,
      roomType = null
    if (data.price && data.price.values) {
      priceData = data.price;
    }
    if (data.roomType && data.roomType.values) {
      roomType = data.roomType.values;
    }

    this.setData({
      selectAreaOne: selectAreaOne,
      showAreaTwo: showAreaTwo,
      areaOne: areaOne,
      areaTwo: areaTwo,
      priceData: priceData,
      homeTypeData: roomType,
      moreData: other,
      sortData: order,
      filtrateData: data
    });
  },

  tapFiltrateAction: function (e) {
    let {
      currentIndex
    } = e.currentTarget.dataset;
    if (this.data.selectdIndex == currentIndex) {
      currentIndex = -1;
    }
    this.setData({
      selectdIndex: currentIndex
    });
  },

  tapAreaOne: function (e) {
    let {
      currentIndex
    } = e.currentTarget.dataset;
    let {
      keys
    } = this.data.areaData[currentIndex];
    let name = this.data.areaOne[currentIndex];


    this.setData({
      selectAreaOne: {
        name: name,
        keys: keys
      },
      showAreaTwo: this.data.areaTwo[name]
    })
  },

  tapAreaTwo: function (e) {
    let {
      currentIndex
    } = e.currentTarget.dataset;
    let {
      name,
      value
    } = this.data.showAreaTwo[currentIndex];
    if (value == -1000) {
      let citySelectObj = util.getStorageSync('citySelectObj');
      this.setData({
        selectdIndex: -1,
        selectAreaTwo: null,
        placeholder: citySelectObj.name,
        houseList: [],
        page: 1
      });
    } else {
      this.setData({
        selectdIndex: -1,
        selectAreaTwo: name,
        placeholder: name,
        houseList: [],
        page: 1
      });
    }


    let upData = this.data.upData;
    this.data.areaData.forEach(element => { // 删除保存的旧数据
      const key = element["keys"];
      if (upData.hasOwnProperty(key)) {
        delete upData[key];
      }
    });
    this.data.upData = upData;

    const key = this.data.selectAreaOne.keys
    let params = {};
    params[key] = value

    this.loadHouseListData(params);
  },

  tapRentItem: function (e) {
    let {
      currentIndex
    } = e.currentTarget.dataset;
    let {
      text,
      minPrice,
      maxPrice
    } = this.data.priceData.values[currentIndex];
    let obj = [minPrice, maxPrice];
    let tmp = this.data.selectPrice || {};
    if (tmp[text]) {
      delete tmp[text]
    } else {
      tmp[text] = obj
    }
    this.setData({
      selectPrice: tmp,
      maxPrice: '',
      minPrice: ''
    });
  },

  bindMinInput: function (e) {
    this.data.minPrice = e.detail.value;
    this.setData({
      selectPrice: null
    });
  },

  bindMaxInput: function (e) {
    this.data.maxPrice = e.detail.value;
    this.setData({
      selectPrice: null
    });
  },

  tapHomeItem: function (e) {
    const obj = this.dealWithSelect(e, this.data.homeTypeData, this.data.selectHomeType);
    this.setData({
      selectHomeType: obj
    })
  },

  tapMoreItem: function (e) {
    const obj = this.dealWithSelect(e, this.data.moreData, this.data.selectMore);
    this.setData({
      selectMore: obj
    })
  },


  dealWithSelect: function (e, originData, showData) {
    let {
      currentIndex,
      idx,
      currentSelect
    } = e.currentTarget.dataset;
    let {
      name,
      values,
      keys
    } = originData[idx];
    let value = values[currentIndex]["value"];
    let tagName = values[currentIndex]["name"];

    let obj = showData;
    if (util.isExist(obj[name])) {
      if (parseInt(currentSelect) == 1) { // 只能单选
        let status = !obj[name][tagName]; // 旧状态取反值
        obj[name] = {}; // 单选全部清空
        obj[name][tagName] = status; // 设置新状态值
      } else if (value == -1000) {
        tagName = infinite;
        const old = util.isExist(obj[name][tagName]) ? obj[name][tagName] : false;
        obj[name] = {};
        obj[upKey][keys] = JSON.stringify([]); // 清除保存的上传数据
        obj[name][tagName] = !old
      } else {
        obj[name][infinite] = false; // 不限不选择
        if (this.judgeValueIsExist(obj, keys, -1000)) { // 将不限数据从上传数据中删除
          obj = this.judgeValueToDeal(obj, keys, -1000)
        }
        obj[name][tagName] = !obj[name][tagName];
      }
    } else {
      obj[name] = {};
      obj[name][tagName] = true;
    }
    obj = this.judgeValueToDeal(obj, keys, value, currentSelect);
    return obj;

  },

  judgeValueToDeal: function (obj, keys, value, select) {
    // 处理选中需要上传的数据
    let upObj = obj[upKey] || {};
    let arr = upObj[keys] ? JSON.parse(upObj[keys]) : new Array();
    var index = arr.indexOf(value);
    if (parseInt(select) == 1) { // 单选先清空已有数据
      arr = new Array();
    }
    if (index != -1) {
      arr.splice(index, 1);
    } else {
      arr.push(value)
    }
    if (arr.length) {
      upObj[keys] = JSON.stringify(arr);
    } else {
      delete upObj[keys];
      delete this.data.upData[keys];
    }
    obj[upKey] = upObj;
    return obj;
  },

  judgeValueIsExist: function (obj, keys, value) { // 数据是否存在
    let upObj = obj[upKey] || {};
    let arr = upObj[keys] || new Array();
    var index = arr.indexOf(value);
    if (index != -1) {
      return true;
    } else {
      return false;
    }
  },

  tapSortAction: function (e) {
    let {
      currentValue
    } = e.currentTarget.dataset;
    this.setData({
      selectdIndex: -1,
      selectSort: currentValue,
      houseList: [],
      page: 1
    });
    this.loadHouseListData();
  },


  tapClearAction: function () {
    const selected = this.data.selectdIndex;
    this.setData({
      houseList: [], // 清空旧数据
      selectdIndex: -1,
      page: 1
    });
    if (selected == 3) {
      const tmp = this.data.selectHomeType[upKey];
      if (tmp && Object.keys(tmp).length) { //清空保存上传数据里面的数据
        for (const key in tmp) {
          if (tmp.hasOwnProperty(key)) {
            delete this.data.upData[key];
          }
        }
      }
      this.setData({
        selectHomeType: {}
      });
      this.loadHouseListData();
    } else if (selected == 4) {
      const tmp = this.data.selectMore[upKey];
      if (tmp && Object.keys(tmp).length) { //清空保存上传数据里面的数据
        for (const key in tmp) {
          if (tmp.hasOwnProperty(key)) {
            delete this.data.upData[key];
          }
        }
      }
      this.setData({
        selectMore: {}
      });
      this.loadHouseListData();
    } else if (selected == 2) {
      this.data.upData["price"] = [];
      this.setData({
        selectPrice: null,
        minPrice: "",
        maxPrice: ""
      });
      this.loadHouseListData();
    }
  },

  tapSureAction: function () {
    const selected = this.data.selectdIndex;
    this.setData({
      houseList: [], // 清空旧数据
      page: 1,
      selectdIndex: -1,
    });
    if (selected == 3) {
      const tmp = this.data.selectHomeType[upKey];
      if (tmp && Object.keys(tmp).length) {
        this.data.selectHomeType.sure = true;
      } else {
        this.data.selectHomeType.sure = false;
      }
      this.setData({
        selectHomeType: this.data.selectHomeType,
      }, () => {
        this.loadHouseListData(tmp);
      })

    } else if (selected == 4) {
      const tmp = this.data.selectMore[upKey];
      if (tmp && Object.keys(tmp).length) {
        this.data.selectMore.sure = true;
      } else {
        this.data.selectMore.sure = false;
      }
      this.setData({
        selectMore: this.data.selectMore,
      }, () => {
        this.loadHouseListData(tmp);
      })
    } else if (selected == 2) {
      const {
        selectPrice,
        minPrice,
        maxPrice
      } = this.data;

      if (selectPrice) {
        let obj = []
        for (const key in selectPrice) {
          if (selectPrice.hasOwnProperty(key)) {
            const element = selectPrice[key];
            if (key != 'sure' && element) {
              obj.push(element);
            }
          }
        }
        if (obj.length == 0) {
          selectPrice.sure = false;
        } else {
          selectPrice.sure = true;
        }
        this.setData({
          selectPrice: selectPrice
        });
        this.loadHouseListData({
          price: JSON.stringify(obj)
        });
      } else if (minPrice.length || maxPrice.length) {
        let selectPrice = this.data.selectPrice || {};
        selectPrice.sure = true;
        this.setData({
          selectPrice: selectPrice
        });
        //  用户只属于最低价或者最高价是，另一个价格为-1000不限
        this.loadHouseListData({
          price: JSON.stringify([
            [parseFloat(minPrice || -1000), parseFloat(maxPrice || -1000)]
          ])
        });
      } else {
        this.loadHouseListData();
      }
    }
    this.data.canLoadMore = true; // 开启可以加载更多模式
  },

  tapMaskAction: function (e) {
    let {
      title
    } = e.currentTarget.dataset;
    if (title == "mask") {
      this.setData({
        selectdIndex: -1
      })
    }
  },
  tapSearchAction: function () {
    wx.navigateTo({
      url: `/pages/search/search`
    });
  },

  // 为了阻断事件透传
  emptyAction: function () {

  }
})