// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const net = require('../../utils/net.js');
const util = require('../../utils/util.js');
import Poster from '../../utils/poster.js'

const {
  api_house_item_detail,
  api_get_QR
} = require('../../utils/api.js');


const app = getApp();
Page({

  /**
   * 页面的初始数据
   */
  data: {
    id: null,
    isLoading: true,
    bannerData: null,
    data: null,
    current: 1,
    markers: null,
    userInfo: null,

    showHomeBtn: false,
    isIPX: app.globalData.isIPX,
    showMask: false,
    posterArr: null,
    template: null,
    postImgSrc: null,
    isShowQRPoster: null,
    isShowCanvas: false,
    isShowPostMask: false,
    extendObj: null,
    shareQRImgSrc: null,


    videoSrc: null,
    poster: null,
    hidden: true

  },

  /**
   * 生命周期函数--监听页面加载 43831
   */
  onLoad: function (options) {
    const {
      scene,
      id,
      shareUid
    } = options;
    if (options && scene) {
      const parmasArr = scene.split('U') // 通过U区分房源id跟用户userCode
      if (Array.isArray(parmasArr)) {
        this.data.id = parmasArr[0]
        this.getRoomDetail();
        if (parmasArr[1] && parmasArr[1].length) {
          const userCode = "U" + parmasArr[1]; // 拼接用户userCode
          util.setStorageSync('shareUid', userCode);
        }
      } else {
        util.showToast("房源正在维护中,请您稍后再试", null, true);
        setTimeout(function () {
          wx.reLaunch({
            url: '/pages/index/index'
          });
        }, 800);
      }
    } else if (options && id) {
      this.data.id = id;
      this.getRoomDetail();
      if (shareUid && shareUid.length) { // 分享用户id
        util.setStorageSync('shareUid', shareUid);
      }
    }
    const pages = getCurrentPages();
    if (pages.length == 1) {
      this.setData({
        showHomeBtn: true
      })
    }

    this.getUserInfo();

  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const {
      share
    } = this.data.data;

    let path = '/pages/roomDetail/roomDetail?id=' + this.data.id;
    const userInfo = util.getStorageSync('userInfo');
    if (userInfo && userInfo.userCode && userInfo.userCode.length) { // 分享用户id
      path = path + '&shareUid=' + userInfo.userCode;
    }

    return {
      title: share.shareTitle + share.shareContent,
      path: path,
      imageUrl: share.shareImgUrl,
      desc: share.shareContent
    }
  },

  loginCallback: function () {
    this.getUserInfo();
  },

  getUserInfo: function () {
    const userInfo = util.getStorageSync("userInfo");
    if (userInfo) {
      this.setData({
        userInfo: userInfo
      })
    }
  },

  getRoomDetail: function () {
    let params = {};
    params.url = api_house_item_detail;
    params.data = {
      roomId: this.data.id
    };
    net.req(params, true).then((data) => {
      this.dealWithData(data);
      this.getBarcode();
    }, (e) => {
      this.setData({
        isLoading: false,
        data: null
      });

      util.showToast(e.msg, null, true);
      setTimeout(function () {
        wx.navigateBack();
      }, 800);
    });

  },

  dealWithData: function (data) {
    let {
      img,
    } = data;
    this.setData({
      isLoading: false,
      data: data,
      markers: [{
        iconPath: '../../imgs/marker.png',
        id: 0,
        latitude: data.locationInfo.lat,
        longitude: data.locationInfo.lng,
        width: 28,
        height: 37
      }]
    });
    let extendObj = {
      img: data.share.shareImgUrl || "https://static.hoolihome.com/weapp/hoolihome/big_16_9.png",
      name: data.share.shareTitle,
      moneyUnit: data.tenancy.moneyUnit,
      price: data.tenancy.price,
      rentTimeUnit: data.tenancy.rentTimeUnitText,
      priceSuffix: data.tenancy.priceSuffix
    }


    if (this.data.userInfo && this.data.userInfo.avatar && this.data.userInfo.avatar.length) {
      extendObj.avatar = this.data.userInfo.avatar
    }

    if (img) {
      this.setData({
        bannerData: data.img || ['https://static.hoolihome.com/weapp/hoolihome/big_16_9.png'],
        extendObj
      });
    }
  },

  tapBannerAction: function (e) {
    const {
      img
    } = this.data.data;
    const {
      bannerItem
    } = e.currentTarget.dataset
    if (parseInt(bannerItem.type) == 2) {
      let videos = new Array()
      for (let i = 0, n = img.length; i < n; i++) {
        const item = img[i];
        if (parseInt(item.type) == 2) {
          videos.push(item);
        }
      }

      if (videos.length == 1) {
        this.setData({
          videoSrc: bannerItem.videoUrl,
          poster: bannerItem.imageUrl,
          hidden: false
        })
      } else {
        const params = {
          videos: videos
        }
        wx.navigateTo({
          url: '/pages/houseVideoImgs/houseVideoImgs?data=' + encodeURIComponent(JSON.stringify(params)) + "&status=" + bannerItem.type
        });
      }
    } else {
      this.lookBigImage(bannerItem.imageUrl);
    }
  },

  hiddenVideoToast: function () {
    this.setData({
      videoSrc: null,
      poster: null,
      hidden: true
    }, () => {

    })
  },


  lookBigImage(imageUrl) {
    const {
      img
    } = this.data.data;
    let imgArr = new Array()
    img.forEach(item => {
      if (parseInt(item.type) == 1) {
        imgArr.push(item.imageUrl)
      }
    });
    wx.previewImage({
      current: imageUrl, // 当前显示图片的http链接
      urls: imgArr // 需要预览的图片http链接列表
    })
  },

  bindchange: function (e) {
    let {
      current
    } = e.detail;
    this.setData({
      current: current + 1
    })
  },



  applyRoomAction: function (e) {
    let data = this.data.data;
    let params = {
      roomId: data.roomId,
      countryId: data.countryId || '',
      cityId: data.cityId || '',
      name: data.roomName,
      rentTime: data.tenancy.rentTime,
      moneyUnit: data.tenancy.moneyUnit,
      price: data.tenancy.price,
      rentTimeUnit: data.tenancy.rentTimeUnitText,
      rentNum: data.tenancy.rentNum,
      id: data.id || ''
    }

    if (data.img && data.img.length) {
      params.imgObj = data.img[0];
    }
    this.openApplyReserve(params);
  },


  openApplyReserve: function (data) {
    if (this.data.userInfo) {
      wx.navigateTo({
        url: '/pages/applyReserve/applyReserve?data=' + JSON.stringify(data)
      });
    } else {
      wx.navigateTo({
        url: '/pages/login/login'
      });
    }
  },


  tapMapAction: function () {
    const data = this.data.data;
    if (data.locationInfo.lat && data.locationInfo.lat.length && data.locationInfo.lng && data.locationInfo.lng.length) {
      const webUrl = decodeURIComponent(data.location) + "&bigMap=map"
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${encodeURIComponent(webUrl)}`
      });
    }
  },

  goHomeAction: function () {
    wx.reLaunch({
      url: '/pages/index/index'
    });
  },

  copyHouseNumAction: function () {
    const {
      roomCode
    } = this.data.data;
    wx.setClipboardData({
      data: roomCode.value,
      success(res) {}
    })
  },


  lookProtocolAction: function () {
    const data = this.data.data;
    if (data.clauseUrl && data.clauseUrl.length) {
      wx.navigateTo({
        url: `/pages/webView/webView?webUrl=${data.clauseUrl}`
      });
    }
  },

  tapLookMoreAction: function (e) {
    const {
      detailUrl
    } = e.currentTarget.dataset
    wx.navigateTo({
      url: `/pages/webView/webView?webUrl=${detailUrl}&name=房间详情`
    });
  },

  lookBuildingAction: function () {
    let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
    let prePage = pages[pages.length - 2]; /*列表页面对象*/
    if (prePage && prePage.route == "pages/houseDetail/houseDetail") {
      wx.navigateBack(-1);
    } else {
      wx.redirectTo({
        url: `/pages/houseDetail/houseDetail?id=${this.data.data.buildingId}`
      });
    }
  },
  shareAction: function () {
    this.setData({
      showMask: true
    });

  },

  getBarcode: function () {
    let {
      userInfo,
      id,
      data
    } = this.data;
    let shareToken = id;
    if (userInfo && userInfo.userCode) {
      shareToken += userInfo.userCode
    }
    shareToken = shareToken.length > 32 ? shareToken.substring(0, 31) : shareToken; // 做容错判断,超过32位
    let params = {};
    params.url = api_get_QR;
    params.data = {
      project: data.share.project,
      scene: shareToken,
      page: data.share.smallProjectPath, //'pages/houseDetail/houseDetail'  
      width: 150,
      contentType: data.share.contentType
    };
    net.req(params).then((res) => {
      let postImgSrc = res.host + res.url;
      this.setData({
        postImgSrc: postImgSrc,
        isShowQRPoster: true
      });
    });
  },

  maskHide: function () {
    this.setData({
      showMask: false
    });
  },

  postMaskHide: function () {
    this.setData({
      isShowPostMask: false
    });
  },

  posterCallack: function (arr) {
    if (!arr) return;
    arr.forEach((v, i, a) => {
      let {
        id,
        dataset
      } = v;
      if (id.indexOf('img') !== -1) {
        wx.getImageInfo({
          src: dataset.what,
          success: (res) => {
            v.dataset.uri = res.path;
          }
        });
      }
    });
    this.data.posterArr = arr

  },
  onImgOK: function (e) {
    const canvasSrc = e.detail.path;
    wx.hideLoading();
    this.setData({
      isShowCanvas: false
    }, () => {
      this.setData({
        shareQRImgSrc: canvasSrc
      })

      wx.previewImage({
        current: canvasSrc, // 当前显示图片的http链接
        urls: [canvasSrc] // 需要预览的图片http链接列表
      })
    });
  },

  handleGeneratePoster: function () {
    const _this = this;
    if (this.data.postImgSrc) {
      if (this.data.shareQRImgSrc) {
        wx.previewImage({
          current: this.data.shareQRImgSrc, // 当前显示图片的http链接
          urls: [this.data.shareQRImgSrc] // 需要预览的图片http链接列表
        })
        return;
      }

      _this.setData({
        showMask: false,
        isShowCanvas: true,
        isShowQRPoster: false
      }, () => {
        let palette = new Poster().palette(this.data.posterArr);
        this.setData({
          template: palette
        });
        wx.showLoading({
          title: '生成海报中...'
        });
      });
    } else {
      util.showToast("海报分享优化中,请使用微信小程序自带分享...", null, true);
    }




  },
  saveImgAction: function () {
    const _this = this;
    wx.saveImageToPhotosAlbum({
      filePath: this.data.shareQRImgSrc,
      success(res) {
        wx.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        });
        _this.setData({
          isShowPostMask: false
        })
      },
      fail() {
        wx.showModal({
          title: '授权失败',
          content: '是否打开小程序设置界面，完成对该小程序授权状态',
          success: function (res) {
            if (res.confirm) {
              wx.openSetting({
                success(res) {}
              })
            }
          }
        })
      }
    })
  }

})