// 请注意常量的命名必须是Page
const Page = require('../../utils/ald-stat.js').Page;
const {
  api_search_house
} = require('../../utils/api.js');
const util = require('../../utils/util.js');
const net = require('../../utils/net.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    dataArr: [],
    searchKey: '',
    historyArr: [],
    showClose: true,
    inputValue: ''
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const historyArr = util.getStorageSync("SEARCHHISTORY");
    if (historyArr && historyArr.length) {
      this.setData({
        historyArr: JSON.parse(decodeURIComponent(historyArr))
      })
    }
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {

  },

  bindSearch: function (e) {
    let {
      value
    } = e.detail;
    if (value && value.trim().length) {
      this.data.searchKey = value;
      let params = {};
      params.url = api_search_house;
      params.data = {
        key: value,
        program: "v2",
        type: "[1,2,3,4,6]"
      };
      net.req(params, true).then((data) => {
        this.dealWithData(data)
      }, (e) => {
        this.setData({
          dataArr: []
        });
      });
    } else {
      this.setData({
        dataArr: [],
        inputValue: ''
      })
    }

  },


  dealWithData: function (arr) {
    if (!arr || !Array.isArray(arr) || arr.length === 0) {
      return false
    }
    const s = `<b style="color:#FF523D;font-size:18px">${this.data.searchKey}</b>`;
    const reg = new RegExp(this.data.searchKey, 'gi')
    arr.forEach((val, i) => {
      let {
        name
      } = val;
      if (name) {
        val.sname = name.replace(reg, s)
      }
    })
    this.setData({
      dataArr: arr
    });
  },

  tapItemAction: function (e) {
    let {
      currentItem
    } = e.currentTarget.dataset;

    let citySelectObj = util.getStorageSync('citySelectObj');
    if (!citySelectObj) {
      wx.reLaunch({
        url: '/pages/citySelect/citySelect',
      });
      return false;
    } else {
      if (parseInt(citySelectObj.conutryId) == parseInt(currentItem.countryId)) {
        if (currentItem.type == 3) {
          wx.navigateTo({
            url: `/pages/houseDetail/houseDetail?id=${currentItem.id}&cityId=${currentItem.cityId}`
          })
        } else {
          let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
          let prePage = pages[pages.length - 2]; /*列表页面对象*/
          if (prePage && prePage.route == "pages/houseList/houseList") {
            let app = getApp();
            app.searchData = encodeURIComponent(JSON.stringify(currentItem));
            if (prePage.updateDataCallback) prePage.updateDataCallback();
            wx.navigateBack();
          } else {
            let path = `/pages/houseList/houseList?obj=${encodeURIComponent(JSON.stringify(currentItem))}`;
            wx.navigateTo({
              url: path
            })
          }
        }
        this.saveHistory(currentItem);
      } else {
        util.showToast(`没有找到房源,请换个搜索条件试试~`, null, true);
      }
    }
  },

  saveHistory: function (item) {
    if (!item) {
      return false
    }
    let historyArr = this.data.historyArr || new Array();
    let arr = []
    if (historyArr.length == 30) {
      historyArr.pop();
    }
    historyArr.forEach(v => {
      if (
        !(v.id == item.id && v.cityId == item.cityId && v.type == item.type)
      ) {
        arr.push(v)
      }
    })
    arr.unshift(item)
    this.setData({
      historyArr: arr
    });
    util.setStorageSync("SEARCHHISTORY", encodeURIComponent(JSON.stringify(arr)));
  },

  clearAllAction: function () {
    this.setData({
      dataArr: [],
      inputValue: ''
    })
  },
  clearHitoryAction: function () {
    util.removeStorageSync("SEARCHHISTORY");
    this.setData({
      historyArr: []
    })
  }

})